---
template: mainpanel
source_form: markdown
name: Trello Cardlist Backlog: Arising
updated: October 2016
title: Trello Cardlist Backlog: Arising
---
### Backlog: Arising

* 259\. Would be nice to remove extraneous brackets round generated C++ expressions
